@@ -48,7 +48,7 @@ TEST(SDFParser, CFMDampingSDFTest)
     unsetenv("SDF_PATH");
   }
 
-  sdf::ElementPtr model = robot->root->GetElement("model");
+  sdf::ElementPtr model = robot->Root()->GetElement("model");
   for (sdf::ElementPtr joint = model->GetElement("joint"); joint;
        joint = joint->GetNextElement("joint"))
   {
@@ -121,7 +121,7 @@ TEST(SDFParser, CFMDampingURDFTest)
     unsetenv("SDF_PATH");
   }
 
-  sdf::ElementPtr model = robot->root->GetElement("model");
+  sdf::ElementPtr model = robot->Root()->GetElement("model");
   for (sdf::ElementPtr joint = model->GetElement("joint"); joint;
        joint = joint->GetNextElement("joint"))
   {
